This application provides a set of demos with X-NUCLEO-NFC01A1 expansion board.

Dependencies:   NDefLib X_NUCLEO_NFC01A1 mbed

Fork of X-MBED-NFC1 by Giovanni Visentini

This application provides a set of demos with X-NUCLEO-NFC01A1 expansion board.

The available demos are:

  • SAMPLE_WRITE_URL: write a tag with the ST home page URL
  • SAMPLE_COUNT_CLICK: create a custom tag to count and report the user button clicks.
  • SAMPLE_WRITE_AND_CHANGE_ALL: write a tag with all the supported records and update the tag contents when the user button is pressed.
  • SAMPLE_LOCK_TAG_CONTENT: use the M24SR component API to set the NFC tag as read-only.

To enable the different demos comment/uncomment the SAMPLE_* macros provided in main.cpp .

Revision:
13:685d95525ec8
Parent:
11:283df715f241
Child:
18:d596eb3f575f
--- a/Samples/Samples.h	Thu Jan 14 09:17:03 2016 +0000
+++ b/Samples/Samples.h	Mon Feb 01 15:33:26 2016 +0000
@@ -1,8 +1,9 @@
 /**
   ******************************************************************************
-  * @file       Samples.h
+  * @file       SamplesSync.h
   * @date       03/12/2015
   * @brief      This file contains definitions for the sample function.
   ******************************************************************************
   *
   * COPYRIGHT(c) 2015 STMicroelectronics
@@ -38,21 +39,25 @@
 /**
  * Wirte a tag with a web site link
  */
-void sample_writeUrl();
+void sampleSync_writeUrl();
+void sampleAsync_writeUrl();
 
 /**
  * Write a castom tag that count how many times the user press the button
  */
-void sample_countClick();
+void sampleSync_countClick();
+void sampleAsync_countClick();
 
 /**
  * Write a message with all the tag, when the user press the button read the message and change the
  * tag content
  */
-void sample_writeAndChangeAll();
+void sampleSync_writeAndChangeAll();
+void sampleAsync_writeAndChangeAll();
 
 /**
  * Set the tag as read only when the user pres the button
  */
-void sample_lockTagContent();
+void sampleSync_lockTagContent();
+void sampleAsync_lockTagContent();
 #endif /* __SAMPLES_H__ */
\ No newline at end of file
@@ -1,8 +1,9 @@
   * @date       03/12/2015
-  * @brief      This file contains definitions for the sample function.
+  * @brief      This file contains definitions for the sample functions that are
+  * that are using the nfc component in a sync way.
   ******************************************************************************
   *